@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.23  Copyright by Tobi Oetiker, 1997-2007
+ * RRDtool 1.2.27  Copyright by Tobi Oetiker, 1997-2008
  *****************************************************************************
  * rrd_create.c  creates new rrds
  *****************************************************************************/
@@ -556,12 +556,7 @@ rrd_create_fn(const char *file_name, rrd_t *rrd)
     
     if ((rrd_file = fopen(file_name,"wb")) == NULL ) {
 	rrd_set_error("creating '%s': %s",file_name, rrd_strerror(errno));
-	free(rrd->stat_head);
-        rrd->stat_head = NULL; 
-	free(rrd->ds_def);
-        rrd->ds_def = NULL; 
-	free(rrd->rra_def);
-        rrd->rra_def = NULL;
+        rrd_free(rrd);
 	return(-1);
     }
     
