@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.23  Copyright by Tobi Oetiker, 1997-2007
+ * RRDtool 1.2.27  Copyright by Tobi Oetiker, 1997-2008
  *****************************************************************************
  * rrd_tool.c  Startup wrapper
  *****************************************************************************/
@@ -22,7 +22,7 @@ void PrintUsage(char *cmd)
 {
 
     char help_main[] =
-	   "RRDtool " PACKAGE_VERSION "  Copyright 1997-2007 by Tobias Oetiker <tobi@oetiker.ch>\n"
+	   "RRDtool " PACKAGE_VERSION "  Copyright 1997-2008 by Tobias Oetiker <tobi@oetiker.ch>\n"
            "               Compiled " __DATE__ " " __TIME__ "\n\n"
 	   "Usage: rrdtool [options] command command_options\n\n";
 
@@ -364,11 +364,8 @@ int main(int argc, char *argv[])
 	  struct rusage  myusage;
 	  struct timeval starttime;
 	  struct timeval currenttime;
-	  struct timezone tz;
 
-	    tz.tz_minuteswest =0;
-	    tz.tz_dsttime=0;
-	    gettimeofday(&starttime,&tz);
+	  gettimeofday(&starttime, NULL);
 #endif
 	  RemoteMode=1;
           if ((argc == 3) && strcmp("",argv[2])){
@@ -426,7 +423,7 @@ int main(int argc, char *argv[])
 
 #if HAVE_GETRUSAGE
  		     getrusage(RUSAGE_SELF,&myusage);
-		     gettimeofday(&currenttime,&tz);
+		     gettimeofday(&currenttime,NULL);
 		     printf("OK u:%1.2f s:%1.2f r:%1.2f\n",
 		       (double)myusage.ru_utime.tv_sec+
 		       (double)myusage.ru_utime.tv_usec/1000000.0,
