@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.23  Copyright by Tobi Oetiker, 1997-2007
+ * RRDtool 1.2.27  Copyright by Tobi Oetiker, 1997-2008
  *****************************************************************************
  * rrd_tool.h   Common Header File
  *****************************************************************************/
@@ -24,12 +24,11 @@ extern "C" {
 #ifdef MUST_DISABLE_FPMASK
 #include <floatingpoint.h>
 #endif
-    
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <string.h>
-#include <time.h>
 #include <ctype.h>
 
 #if HAVE_SYS_PARAM_H
@@ -72,23 +71,8 @@ extern "C" {
 # include <sys/stat.h>
 #endif
 
-
-#if HAVE_UNISTD_H
-# include <unistd.h>
-#endif
-#if HAVE_SYS_TIME_H
-# include <sys/time.h>
-#endif
-#if HAVE_SYS_TIMES_H
-# include <sys/times.h>
-#endif
-#if HAVE_SYS_RESOURCE_H
-# include <sys/resource.h>
-#if (defined(__svr4__) && defined(__sun__))
-/* Solaris headers (pre 2.6) don't have a getrusage prototype.
-   Use this instead. */
-extern int getrusage(int, struct rusage *);
-#endif /* __svr4__ && __sun__ */
+#if HAVE_STRINGS_H
+# include <strings.h>
 #endif
 
 #include "rrd.h"
@@ -108,7 +92,7 @@ char *strtok_r(char *str, const char *sep, char **last);
 #else
 
 /* unix-only includes */
-#ifndef isnan
+#if !defined isnan && !defined HAVE_ISNAN
 int isnan(double value);
 #endif
 
