@@ -1,17 +1,14 @@
 /*****************************************************************************
- * RRDtool 1.2.23  Copyright by Tobi Oetiker, 1997-2007
+ * RRDtool 1.2.27  Copyright by Tobi Oetiker, 1997-2008
  *****************************************************************************
  * rrd_update.c  RRD Update Function
  *****************************************************************************
- * $Id: rrd_update.c 1050 2007-05-02 18:06:05Z oetiker $
+ * $Id: rrd_update.c 1286 2008-02-17 10:08:10Z oetiker $
  *****************************************************************************/
 
 #include "rrd_tool.h"
 #include <sys/types.h>
 #include <fcntl.h>
-#ifdef HAVE_MMAP
- #include <sys/mman.h>
-#endif
 
 #if defined(_WIN32) && !defined(__CYGWIN__) && !defined(__CYGWIN32__)
  #include <sys/locking.h>
@@ -32,12 +29,15 @@
  */
 #include <sys/timeb.h>
 
-#ifndef __MINGW32__
+#if (defined(__MINGW32__) && \
+       ((__MINGW32_MAJOR_VERSION == 3 && __MINGW32_MINOR_VERSION >= 12) || __MINGW32_MAJOR_VERSION > 3))
+#include <sys/time.h>
+#else
+
 struct timeval {
 	time_t tv_sec; /* seconds */
 	long tv_usec;  /* microseconds */
 };
-#endif
 
 struct __timezone {
 	int  tz_minuteswest; /* minutes W of Greenwich */
@@ -56,7 +56,9 @@ static int gettimeofday(struct timeval *t, struct __timezone *tz) {
 	return 0;
 }
 
+#endif /* mingw32 3.4.5 */
 #endif
+
 /*
  * normilize time as returned by gettimeofday. usec part must
  * be always >= 0
@@ -261,6 +263,7 @@ _rrd_update(const char *filename, const char *tmplt, int argc, const char **argv
     rpnstack_t       rpnstack; /* used for COMPUTE DS */
     int		     version;  /* rrd version */
     char             *endptr; /* used in the conversion */
+
 #ifdef HAVE_MMAP
     void	     *rrd_mmaped_file;
     unsigned long    rrd_filesize;
@@ -280,6 +283,7 @@ _rrd_update(const char *filename, const char *tmplt, int argc, const char **argv
     if(rrd_open(filename,&rrd_file,&rrd, RRD_READWRITE)==-1){
 	return -1;
     }
+
     /* initialize time */
     version = atoi(rrd.stat_head->version);
     gettimeofday(&tmp_time, 0);
@@ -425,6 +429,11 @@ _rrd_update(const char *filename, const char *tmplt, int argc, const char **argv
         fclose(rrd_file);
 	return(-1);
     }
+#ifdef USE_MADVISE
+    /* when we use mmaping we tell the kernel the mmap equivalent
+       of POSIX_FADV_RANDOM */
+    madvise(rrd_mmaped_file,rrd_filesize,MADV_RANDOM);
+#endif
 #endif
     /* loop through the arguments. */
     for(arg_i=0; arg_i<argc;arg_i++) {
@@ -613,16 +622,16 @@ _rrd_update(const char *filename, const char *tmplt, int argc, const char **argv
 		switch(dst_idx){
 		case DST_COUNTER:
 		case DST_DERIVE:
+            for(ii=0;updvals[i+1][ii] != '\0';ii++){
+                 if((updvals[i+1][ii] < '0' || updvals[i+1][ii] > '9') && (ii != 0 && updvals[i+1][ii] != '-')){
+                      rrd_set_error("not a simple integer: '%s'",updvals[i+1]);
+                      break;
+                 }
+            }
+            if (rrd_test_error()){
+                   break;
+            }
 		    if(rrd.pdp_prep[i].last_ds[0] != 'U'){
-                      for(ii=0;updvals[i+1][ii] != '\0';ii++){
-                            if((updvals[i+1][ii] < '0' || updvals[i+1][ii] > '9') && (ii != 0 && updvals[i+1][ii] != '-')){
-                                 rrd_set_error("not a simple integer: '%s'",updvals[i+1]);
-                                 break;
-                            }
-                       }
-                       if (rrd_test_error()){
-                            break;
-                       }
 		       pdp_new[i]= rrd_diff(updvals[i+1],rrd.pdp_prep[i].last_ds);
 		       if(dst_idx == DST_COUNTER) {
 			  /* simple overflow catcher suggested by Andres Kroonmaa */
@@ -1193,7 +1202,7 @@ _rrd_update(const char *filename, const char *tmplt, int argc, const char **argv
 		i < rrd.stat_head->rra_cnt;
 	    rra_start += rrd.rra_def[i].row_cnt * rrd.stat_head -> ds_cnt * sizeof(rrd_value_t),
 		i++) {
-		/* is there anything to write for this RRA? If not, continue. */
+		/* is th5Aere anything to write for this RRA? If not, continue. */
         if (rra_step_cnt[i] == 0) continue;
 
 		/* write the first row */
@@ -1396,7 +1405,7 @@ _rrd_update(const char *filename, const char *tmplt, int argc, const char **argv
 	fclose(rrd_file);
 	return(-1);
     }
-
+    
     /* OK now close the files and free the memory */
     if(fclose(rrd_file) != 0){
 	rrd_set_error("closing rrd");
@@ -1416,6 +1425,8 @@ _rrd_update(const char *filename, const char *tmplt, int argc, const char **argv
 	if (schedule_smooth)
 	{
 	  rrd_file = fopen(filename,"rb+");
+          
+
 	  rra_start = rra_begin;
 	  for (i = 0; i < rrd.stat_head -> rra_cnt; ++i)
 	  {
